@@ -121,7 +121,7 @@ typedef struct {
 
 	/* <private> */
 	int expansion[30]; /* what is this for? */
-	unsigned ref_count;
+	unsigned int ref_count;
 } GOFormatDetails;
 
 GType go_format_details_get_type (void);
@@ -279,6 +279,12 @@ GOFormatCurrency const *go_format_locale_currency (void);
 
 /*************************************************************************/
 
+GOColor go_format_palette_color_of_index (int i);
+int go_format_palette_index_from_color (GOColor c);
+char *go_format_palette_name_of_index (int i);
+
+/*************************************************************************/
+
 void _go_number_format_init (void);
 void _go_number_format_shutdown (void);
 void _go_currency_date_format_init     (void);
